@@ -8,8 +8,8 @@
 #include <inttypes.h>
 #include <event2/event.h>
 
-#include "../evhtp-internal.h"
-#include "../evhtp.h"
+#include "internal.h"
+#include "evhtp/evhtp.h"
 
 
 #ifndef EVHTP_DISABLE_EVTHR
@@ -97,9 +97,15 @@ pause_init_cb(evhtp_request_t * req, evhtp_path_t * path, void * arg) {
     pause->timer_ev = evtimer_new(evbase, resume_request_timer, pause);
     pause->request  = req;
 
-    evhtp_set_hook(&req->hooks, evhtp_hook_on_header, pause_cb, pause);
-    evhtp_set_hook(&req->hooks, evhtp_hook_on_request_fini, pause_request_fini, pause);
-    evhtp_set_hook(&req->conn->hooks, evhtp_hook_on_connection_fini, pause_connection_fini, NULL);
+    evhtp_request_set_hook(req,
+            evhtp_hook_on_header, pause_cb, pause);
+
+    evhtp_request_set_hook(req,
+            evhtp_hook_on_request_fini, pause_request_fini, pause);
+
+    evhtp_connection_set_hook(req->conn,
+            evhtp_hook_on_connection_fini,
+            pause_connection_fini, NULL);
 
     return EVHTP_RES_OK;
 }
@@ -136,7 +142,7 @@ test_ownership(evhtp_request_t * request, void * arg) {
 static void
 test_regex(evhtp_request_t * req, void * arg) {
     evbuffer_add_printf(req->buffer_out,
-                        "start = '%s', end = '%s\n",
+                        "rest_regex start = '%s', end = '%s\n",
                         req->uri->path->match_start,
                         req->uri->path->match_end);
 
@@ -377,14 +383,13 @@ set_my_connection_handlers(evhtp_connection_t * conn, void * arg) {
     struct timeval               tick;
     struct ev_token_bucket_cfg * tcfg = NULL;
 
-    evhtp_set_hook(&conn->hooks, evhtp_hook_on_header, print_kv, "foo");
-    evhtp_set_hook(&conn->hooks, evhtp_hook_on_headers, print_kvs, "bar");
-    evhtp_set_hook(&conn->hooks, evhtp_hook_on_path, print_path, "baz");
-    evhtp_set_hook(&conn->hooks, evhtp_hook_on_read, print_data, "derp");
-    evhtp_set_hook(&conn->hooks, evhtp_hook_on_new_chunk, print_new_chunk_len, NULL);
-    evhtp_set_hook(&conn->hooks, evhtp_hook_on_chunk_complete, print_chunk_complete, NULL);
-    evhtp_set_hook(&conn->hooks, evhtp_hook_on_chunks_complete, print_chunks_complete, NULL);
-    /* evhtp_set_hook(&conn->hooks, evhtp_hook_on_hostname, print_hostname, NULL); */
+    evhtp_connection_set_hook(conn, evhtp_hook_on_header, print_kv, "foo");
+    evhtp_connection_set_hook(conn, evhtp_hook_on_headers, print_kvs, "bar");
+    evhtp_connection_set_hook(conn, evhtp_hook_on_path, print_path, "baz");
+    evhtp_connection_set_hook(conn, evhtp_hook_on_read, print_data, "derp");
+    evhtp_connection_set_hook(conn, evhtp_hook_on_new_chunk, print_new_chunk_len, NULL);
+    evhtp_connection_set_hook(conn, evhtp_hook_on_chunk_complete, print_chunk_complete, NULL);
+    evhtp_connection_set_hook(conn, evhtp_hook_on_chunks_complete, print_chunks_complete, NULL);
 
     if (bw_limit > 0) {
         tick.tv_sec  = 0;
@@ -395,7 +400,7 @@ set_my_connection_handlers(evhtp_connection_t * conn, void * arg) {
         bufferevent_set_rate_limit(conn->bev, tcfg);
     }
 
-    evhtp_set_hook(&conn->hooks, evhtp_hook_on_request_fini, test_fini, tcfg);
+    evhtp_connection_set_hook(conn, evhtp_hook_on_request_fini, test_fini, tcfg);
 
     return EVHTP_RES_OK;
 }
@@ -426,6 +431,12 @@ const char * help   =
     "  -s <pem> : Enable SSL and PEM       (default: NULL)\n"
     "  -c <ca>  : CA cert file             (default: NULL)\n"
     "  -C <path>: CA Path                  (default: NULL)\n"
+    "  (to test: \n"
+    "            openssl genrsa -out pkey 2048\n"
+    "            openssl req -new -key pkey -out cert.req\n"
+    "            openssl x509 -req -days 365 -in cert.req -signkey pkey -out cert\n"
+    "            cat pkey cert > test_cert\n"
+    "             then use -s test_cert\n"
 #endif
     "  -l <int> : Max bandwidth (in bytes) (default: NULL)\n"
     "  -r <str> : Document root            (default: .)\n"
@@ -537,12 +548,11 @@ main(int argc, char ** argv) {
     evbase = event_base_new();
     htp    = evhtp_new(evbase, NULL);
 
+    evhtp_enable_flag(htp, EVHTP_FLAG_ENABLE_REUSEPORT);
     evhtp_set_parser_flags(htp, EVHTP_PARSE_QUERY_FLAG_LENIENT);
+
     evhtp_set_max_keepalive_requests(htp, max_keepalives);
 
-    /* htp->enable_nodelay = 1; */
-    /* htp->enable_defer_accept = 1; */
-    htp->enable_reuseport = 1;
 
     cb_1  = evhtp_set_cb(htp, "/ref", test_default_cb, "fjdkls");
     evhtp_assert(cb_1 != NULL);
@@ -586,14 +596,14 @@ main(int argc, char ** argv) {
     evhtp_assert(cb_12 != NULL);
 
     /* set a callback to pause on each header for cb_7 */
-    evhtp_set_hook(&cb_7->hooks, evhtp_hook_on_path, pause_init_cb, NULL);
+    evhtp_callback_set_hook(cb_7, evhtp_hook_on_path, pause_init_cb, NULL);
 
     /* set a callback to set hooks specifically for the cb_6 callback */
 #ifndef EVHTP_DISABLE_REGEX
-    evhtp_set_hook(&cb_6->hooks, evhtp_hook_on_headers, test_regex_hdrs_cb, NULL);
+    evhtp_callback_set_hook(cb_6, evhtp_hook_on_headers, test_regex_hdrs_cb, NULL);
 #endif
 
-    evhtp_set_hook(&cb_10->hooks, evhtp_hook_on_headers, set_max_body, NULL);
+    evhtp_callback_set_hook(cb_10, evhtp_hook_on_headers, set_max_body, NULL);
 
     /* set a default request handler */
     evhtp_set_gencb(htp, test_default_cb, "foobarbaz");
@@ -644,7 +654,7 @@ main(int argc, char ** argv) {
 
 #ifndef EVHTP_DISABLE_EVTHR
     if (use_threads) {
-        evhtp_use_threads(htp, NULL, num_threads, NULL);
+        evhtp_use_threads_wexit(htp, NULL, NULL, num_threads, NULL);
     }
 #endif
 
